@@ -24,7 +24,10 @@ import logging
 import os
 
 _DEFAULT_CONFIG = {
+    'source': '',
+    'destination': '_build',
     'img_size': (640, 480),
+    'img_processor': 'ResizeToFit',
     'make_thumbs': True,
     'thumb_prefix': '',
     'thumb_suffix': '',
@@ -37,6 +40,7 @@ _DEFAULT_CONFIG = {
     'copyright': '',
     'ext_list': ['.jpg', '.jpeg', '.JPG', '.JPEG', '.png'],
     'theme': 'colorbox',
+    'write_html': True,
     'index_in_url': False,
     'links': '',
     'google_analytics': ''
@@ -52,18 +56,41 @@ def get_thumb(settings, filename):
                         name + settings['thumb_suffix'] + ext)
 
 
+def get_orig(settings, filename):
+    """Return the path to the original image."""
+
+    path, filen = os.path.split(filename)
+    return os.path.join(path, settings['orig_dir'], filen)
+
+
 def read_settings(filename=None):
     """Read settings from a config file in the source_dir root."""
 
     logger = logging.getLogger(__name__)
+    logger.info("Reading settings ...")
     settings = _DEFAULT_CONFIG.copy()
+    settings_path = os.path.dirname(filename)
 
     if filename:
+        logger.debug("Settings file: %s", filename)
         tempdict = {}
         execfile(filename, tempdict)
         settings.update((k, v) for k, v in tempdict.iteritems()
                         if k not in ['__builtins__'])
 
+        # Make the paths relative to the settings file
+        paths = ['source', 'destination']
+
+        if os.path.isdir(os.path.join(settings_path, settings['theme'])):
+            paths.append('theme')
+
+        for p in paths:
+            path = settings[p]
+            if path and not os.path.isabs(path):
+                settings[p] = os.path.abspath(os.path.normpath(os.path.join(
+                    settings_path, path)))
+                logger.debug("Rewrite %s : %s -> %s", p, path, settings[p])
+
     for key in ('img_size', 'thumb_size'):
         w, h = settings[key]
         if h > w:
